<?php
/**
 * Created by JetBrains PhpStorm.
 * User: geovanesantos
 * Date: 04/09/14
 * Time: 12:37
 * To change this template use File | Settings | File Templates.
 */

namespace Scheduler\Util;


class ReportParameterFunctions {


    public static function buildParametersFromAmbiente(){
        $returnArray["URL_LOGO_CLIENTE"]=\Geral\Util\Ambiente::retornaCaminhoLogoCliente();
        $returnArray["P_NRORG"]=\Geral\Util\Ambiente::getNrorgTrabalho();
        return $returnArray;
    }


    /**
     * Retorna um array com dois parâmetros de data, em formato de string, que compreendem um período,
     * num formato utilizado por \Scheduler\Logic\Report.
     * O primeiro pode ser construído a partir do valor de um campo com nome "P_DATAFIM"
     * ou de um DateTime passado em $dataFim
     * e o outro é o primeiro dia do mês/ano da data <"P_DATAFIM" - o intervalo passado>
     *
     * @param $intervalString - O intervalo de diferença entre os dois parâmetros, como um DateInterval ou uma string
     * de intervalo válida
     * @param string $initDateParamName - O nome do parâmetro de data inicial no relatório
     * @param string $endDateParamName - O nome do parâmetro de data final no relatório
     * @return Array Os dois parâmetros, num array associativo
     *
     */
    public static function buildDateParametersFromInterval($intervalString, $dataFim=null, $initDateParamName="P_DATAINICIO",
                                                           $endDateParamName="P_DATAFIM"){
        if($dataFim===null || !($dataFim instanceof \DateTime)){
            $dataFim=date_create_from_format("d/m/Y", tk_get_field_value("P_DATAFIM"));
        }
        $interval=new \DateInterval($intervalString);
        if($dataFim->format('d')==1){ //se dataFim é o primeiro dia do mês
            $dataFim->sub(new \DateInterval("P1D")); //torna-se o último do mês anterior, para o relatório abranger alguma data
        }
        //a data de inicio é uma cópia da data de fim
        $dataInicio=\DateTime::createFromFormat("d/m/Y", $dataFim->format("d/m/Y"));
        $dataInicio->sub($interval);  //menos o intervalo

        $returnArray[$initDateParamName]=$dataInicio->format("01/m/Y");
        $returnArray[$endDateParamName]=$dataFim->format("d/m/Y");

        return $returnArray;
    }

    public static function makeParamFromCallback($paramName, $callBack){

        return Array($paramName=>$callBack());
    }

    public static function getInfoFromMultiSearchString($searchArray, $fieldName){

        //Quando o multisearch está marcado como "Todos", ele retorna "A"
        //Se retornar "A" (ou "N"), considera-se que não se quer filtrar,
        //e o parâmetro de filial é setado como T (que o relatório entende como "todos")

        if($searchArray!="A"&&$searchArray!="N"&&is_array($searchArray)){
            //$searchArray é um array de arrays, e o que se deseja está no array de dentro
            //é necessário iterar o array e pegar os códigos de lá
            $returnArray=Array();
            foreach($searchArray as $item){
                $returnArray[]=$item[$fieldName];
            }

            $returnString=implode($returnArray,",");
            //implode retorna false se receber um array vazio, mas precisa ser passado
            //teoricamente o multisearch não poderia retornar um array vazio, isso é só pra garantir

            if(!empty($returnString)){
                return $returnString;
            }
            else{
                return 'T';
            }
        }
        else return 'T';

    }

}