/*
 Tecnisa - Tecnologia em Informtica

 Nome: Limpeza de Dados do Planejamento
 Tabelas de log e movimentao menos usadas:

CNFCAMES
CUSTPADR
CUSTNESTO
CONSSERV
DIASEMCONS
SERVTRAN

LOGPREVCONS
LOGPREVRETI
LOGSERVTRAN
LOGSUBCONSSER
LOGINTCARD

 Criao:
30/11/05 Dmaso

@C:\web_405\cli\src\cli\GRS\SQL\0310_PLASTPO_Limpeza_Planejamento_GR.sql
*/

CREATE OR REPLACE PROCEDURE LIMPEZA_PLA_GR(
   P_DTLIMPEZA IN DATE)
AS
   V_DTMAX DATE;
   V_DTFINAL DATE;
BEGIN
   V_DTMAX := SYSDATE - 365;
   IF P_DTLIMPEZA > V_DTMAX THEN
      RAISE_APPLICATION_ERROR(-20999, 'Data informada deve ser anterior a 1 ano.');
   ELSE
      V_DTFINAL := P_DTLIMPEZA + 1;
      FOR C_FILIAL IN
      (SELECT CDFILIAL FROM (
       SELECT
          DISTINCT CDFILIAL
       FROM CNFCAMES
       WHERE
          DTREFECNFMES < V_DTFINAL
       UNION
       SELECT
          DISTINCT CDFILIAL
       FROM CUSTPADR
       WHERE
          DTREFCUSPADR < V_DTFINAL
       UNION
       SELECT
          DISTINCT CDFILIAL
       FROM CUSTNESTO
       WHERE
          DTCUSTNESTO < V_DTFINAL
       UNION
       SELECT
          DISTINCT CDFILIAL
       FROM CONSSERV
       WHERE
          DTCONSSERV < V_DTFINAL
       UNION
       SELECT
          DISTINCT CDFILIAL
       FROM DIASEMCONS
       WHERE
          DTSCONSSERV < V_DTFINAL
       UNION
       SELECT
          DISTINCT CDFILIAL
       FROM SERVTRAN
       WHERE
          DTSERVTRAN < V_DTFINAL)
       )
      LOOP
         /* Log da Previso de Consumo */
         FOR C_LOGPREVCONS IN
         (SELECT
            ROWID LINHA
          FROM
            LOGPREVCONS
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTHRCALCPC < V_DTFINAL)
         LOOP
            DELETE FROM LOGPREVCONS
            WHERE
               ROWID = C_LOGPREVCONS.LINHA;
         END LOOP;
         COMMIT;

         /* Log da Requisicao */
         FOR C_LOGPREVRETI IN
         (SELECT
            ROWID LINHA
          FROM
            LOGPREVRETI
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTHRCALCPR < V_DTFINAL)
         LOOP
            DELETE FROM LOGPREVRETI
            WHERE
               ROWID = C_LOGPREVRETI.LINHA;
         END LOOP;
         COMMIT;

         /* Log de Servios Transportados */
         FOR C_LOGSERVTRAN IN
         (SELECT
            ROWID LINHA
          FROM
            LOGSERVTRAN
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTHRCALCST < V_DTFINAL)
         LOOP
            DELETE FROM LOGSERVTRAN
            WHERE
               ROWID = C_LOGSERVTRAN.LINHA;
         END LOOP;
         COMMIT;

         /* Configurao Mensal do Cardpio */
         FOR C_CNFCAMES IN
         (SELECT
            ROWID LINHA
          FROM
            CNFCAMES
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTREFECNFMES < V_DTFINAL)
         LOOP
            DELETE FROM CNFCAMES
            WHERE
               ROWID = C_CNFCAMES.LINHA;
         END LOOP;
         COMMIT;

         /* Custo Padro Mensal do Servio */
         FOR C_CUSTPADR IN
         (SELECT
            ROWID LINHA
          FROM
            CUSTPADR
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTREFCUSPADR < V_DTFINAL)
         LOOP
            DELETE FROM CUSTPADR
            WHERE
               ROWID = C_CUSTPADR.LINHA;
         END LOOP;
         COMMIT;

         /* Custo de No-Estocveis Mensal */
         FOR C_CUSTNESTO IN
         (SELECT
            ROWID LINHA
          FROM
            CUSTNESTO
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTCUSTNESTO < V_DTFINAL)
         LOOP
            DELETE FROM CUSTNESTO
            WHERE
               ROWID = C_CUSTNESTO.LINHA;
         END LOOP;
         COMMIT;

         /* Consumo por Servio */
         FOR C_CONSSERV IN
         (SELECT
            ROWID LINHA
          FROM
            CONSSERV
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTCONSSERV < V_DTFINAL)
         LOOP
            DELETE FROM CONSSERV
            WHERE
               ROWID = C_CONSSERV.LINHA;
         END LOOP;
         COMMIT;

         /* Dias sem consumo */
         FOR C_DIASEMCONS IN
         (SELECT
            ROWID LINHA
          FROM
            DIASEMCONS
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTSCONSSERV < V_DTFINAL)
         LOOP
            DELETE FROM DIASEMCONS
            WHERE
               ROWID = C_DIASEMCONS.LINHA;
         END LOOP;
         COMMIT;

         /* Servios Transportados */
         FOR C_SERVTRAN IN
         (SELECT
            ROWID LINHA
          FROM
            SERVTRAN
          WHERE
            CDFILIAL = C_FILIAL.CDFILIAL AND
            DTSERVTRAN < V_DTFINAL)
         LOOP
            DELETE FROM SERVTRAN
            WHERE
               ROWID = C_SERVTRAN.LINHA;
         END LOOP;
         COMMIT;

      END LOOP;

      /* Log de Substituio de Cons. Servio */
      FOR C_LOGSUBCONSSER IN
      (SELECT
         ROWID LINHA
       FROM
         LOGSUBCONSSER
       WHERE
         DTOPERSUB < V_DTFINAL)
      LOOP
         DELETE FROM LOGSUBCONSSER
         WHERE
            ROWID = C_LOGSUBCONSSER.LINHA;
      END LOOP;
      COMMIT;

      DELETE FROM LOGINTCARD;
      COMMIT;
   END IF;
END;
/